"""
ScreenPy Adapter: Allure
"""
# (the ascii art would be too long for this one :( )


__title__ = "screenpy_adapter_allure"
__description__ = "ScreenPy Adapter to log test steps to Allure."
__url__ = "https://github.com/ScreenPyHQ/screenpy_adapter_allure"
__version__ = "4.0.2"
__author__ = "Perry Goy"
__author_email__ = "perry.goy@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2022-2023 Perry Goy"
